@@ -1,8 +1,9 @@
 /* GDA Common Library
- * Copyright (C) 1998-2002 The GNOME Foundation.
+ * Copyright (C) 1998 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -20,9 +21,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if !defined(__gda_command_h__)
-#  define __gda_command_h__
+#ifndef __GDA_COMMAND_H__
+#define __GDA_COMMAND_H__
 
+#include <glib-object.h>
 #include <glib/gmacros.h>
 #include <glib/gtypes.h>
 
@@ -41,25 +43,32 @@ typedef enum {
 	GDA_COMMAND_TYPE_XML,
 	GDA_COMMAND_TYPE_PROCEDURE,
 	GDA_COMMAND_TYPE_TABLE,
+	GDA_COMMAND_TYPE_SCHEMA,
 	GDA_COMMAND_TYPE_INVALID
 } GdaCommandType;
 
-typedef struct {
-	gchar *text;
-	GdaCommandType type;
-	GdaCommandOptions options;
-} GdaCommand;
+typedef struct _GdaCommand GdaCommand;
 
-GdaCommand    *gda_command_new (const gchar *text, GdaCommandType type,
-				GdaCommandOptions options);
-void           gda_command_free (GdaCommand *cmd);
+struct _GdaCommand {
+	gchar             *text;
+	GdaCommandType     type;
+	GdaCommandOptions  options;
+};
 
-const gchar   *gda_command_get_text (GdaCommand *cmd);
-void           gda_command_set_text (GdaCommand *cmd, const gchar *text);
-GdaCommandType gda_command_get_command_type (GdaCommand *cmd);
-void           gda_command_set_command_type (GdaCommand *cmd, GdaCommandType type);
+#define GDA_TYPE_COMMAND (gda_command_get_type ())
+
+GType             gda_command_get_type (void);
+GdaCommand       *gda_command_new (const gchar *text, GdaCommandType type,
+				   GdaCommandOptions options);
+void              gda_command_free (GdaCommand *cmd);
+GdaCommand       *gda_command_copy (GdaCommand *cmd);
+
+const gchar      *gda_command_get_text (GdaCommand *cmd);
+void              gda_command_set_text (GdaCommand *cmd, const gchar *text);
+GdaCommandType    gda_command_get_command_type (GdaCommand *cmd);
+void              gda_command_set_command_type (GdaCommand *cmd, GdaCommandType type);
 GdaCommandOptions gda_command_get_options (GdaCommand *cmd);
-void           gda_command_set_options (GdaCommand *cmd, GdaCommandOptions options);
+void              gda_command_set_options (GdaCommand *cmd, GdaCommandOptions options);
 
 G_END_DECLS
 
