@@ -25,7 +25,7 @@
 #include <glib/gmacros.h>
 #include <libgda/gda-connection.h>
 #include <libgda/gda-server-provider.h>
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
 #include "gda-msql-provider.h"
 #include <msql.h>
 
@@ -33,9 +33,9 @@
 
 G_BEGIN_DECLS
 
-GdaError     *gda_msql_make_error(int sock);
-GdaValueType  gda_msql_type_to_gda(int msql_type);
-gchar        *gda_msql_value_to_sql_string(GdaValue *val);
+GdaConnectionEvent     *gda_msql_make_error(int sock);
+GType  gda_msql_type_to_gda(int msql_type);
+gchar        *gda_msql_value_to_sql_string(GValue *val);
 
 G_END_DECLS 
 
